logConDens,
activeSetLogCon, or activeSetLogCon.mode,
this function gives a function $\widehat I$ given by $$\widehat I(l,r) = \int_{l}^{r} \widehat{F}(u) d u$$
or by
$$\widehat I(l,r) = \int_{l}^{r} (1-\widehat{F}(u)) d u$$
Note that $l$ and $r$ must lie in $[x_1,x_m]$. For exact formulas
related to these integrals, see the intF function.
intFfn(x, phi, Fhat, prec = 1e-10, side = "left")preProcess, potentially with a constrainx that gives the log-concave
estimate's values at x.x that gives the log-concave
estimate CDF's values at x.intF function.side is "left" then the return is of type
function(upper, lower=rep(x[1],length(upper))). If side is "right" then the return is of type
function(lower, upper=rep(x[length(x)],length(lower))). Note
that the order of the arguments are changed, so that passing an
unnamed numeric value or vector has a default behavior of integrating
"from the outside-in".Duembgen, L. and Rufibach, K. (2009) Maximum likelihood estimation of a log-concave density and its distribution function: basic properties and uniform consistency. Bernoulli, 15(1), 40--68.
Duembgen, L. and Rufibach, K. (2011) logcondens: Computations
Related to Univariate Log-Concave Density Estimation.
Journal of Statistical Software, 39(6),
1--28.
Doss, C. R. (2013). Shape-Constrained Inference for Concave-Transformed Densities and their Modes. PhD thesis, Department of Statistics, University of Washington, in preparation.
Doss, C. R. and Wellner, J. A. (2013). Inference for the mode of a log-concave density. Technical Report, University of Washington, in preparation.
activeSetLogCon or
activeSetLogCon.mode. The function intECDFfn
is similar, but based on the empirical distribution function. The
function intF behaves similarly but returns a vector
instead of a function.## estimate gamma density
set.seed(1977)
x <- rgamma(200, 2, 1)
res <- activeSetLogCon.mode(x, mode=1)
## res$x is not equal to x
myIntF <- intFfn( res$x, res$phi, res$Fhat, side="left")
s <- seq(min(res$x), max(res$x), by = 10 ^ -3)
D1 <- myIntF(s)Run the code above in your browser using DataLab